@@ -1,24 +1,9 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2013-2015 Vishesh Handa <vhanda@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE Baloo Project
+    SPDX-FileCopyrightText: 2013-2015 Vishesh Handa <vhanda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include <QCoreApplication>
 #include <QCommandLineParser>
@@ -31,7 +16,8 @@
 #include <KLocalizedString>
 
 #include "query.h"
-#include "searchstore.h"
+
+#include <iostream>
 
 int main(int argc, char* argv[])
 {
@@ -80,10 +66,7 @@ int main(int argc, char* argv[])
     if (parser.isSet(QStringLiteral("offset")))
         offset = parser.value(QStringLiteral("offset")).toInt();
 
-    QTextStream out(stdout);
-    QTextStream err(stderr);
-
-    QString queryStr = args.join(QStringLiteral(" "));
+    QString queryStr = args.join(QLatin1Char(' '));
 
     Baloo::Query query;
     query.addType(typeStr);
@@ -93,7 +76,12 @@ int main(int argc, char* argv[])
 
     if (parser.isSet(QStringLiteral("directory"))) {
         QString folderName = parser.value(QStringLiteral("directory"));
-        query.setIncludeFolder(QFileInfo(folderName).canonicalFilePath());
+        const QFileInfo fi(folderName);
+        if (!fi.isDir()) {
+            std::cerr << qPrintable(i18n("%1 is not a valid directory", folderName)) << std::endl;
+            return 1;
+        }
+        query.setIncludeFolder(fi.canonicalFilePath());
     }
 
     QElapsedTimer timer;
@@ -102,9 +90,9 @@ int main(int argc, char* argv[])
     Baloo::ResultIterator iter = query.exec();
     while (iter.next()) {
         const QString filePath = iter.filePath();
-        out << filePath << endl;
+        std::cout << qPrintable(filePath) << std::endl;
     }
-    err << i18n("Elapsed: %1 msecs", timer.nsecsElapsed() / 1000000.0) << endl;
+    std::cerr << qPrintable(i18n("Elapsed: %1 msecs", timer.nsecsElapsed() / 1000000.0)) << std::endl;
 
     return 0;
 }
